@@ -6,7 +6,9 @@
 #include <memory>
 
 #include <base/hash.h>
-#include <engine/shared/http.h>
+#include <engine/client/http.h>
+
+#define CONNECTLINK "ddnet:"
 
 class CGraph
 {
@@ -382,6 +384,8 @@ public:
 
 	void ServerBrowserUpdate();
 
+	void HandleConnectLink(const char *pLink);
+
 	// gfx
 	void SwitchWindowScreen(int Index);
 	void ToggleFullscreen();
