@@ -104,7 +104,9 @@ void CCollision::Init(class CLayers *pLayers)
 
 			if(Index <= TILE_NPH_START)
 			{
-				if(Index >= TILE_JUMP && Index <= TILE_BONUS)
+				if((Index >= TILE_JUMP && Index <= TILE_BONUS)
+						|| Index == TILE_ALLOW_TELE_GUN
+						|| Index == TILE_ALLOW_BLUE_TELE_GUN)
 					m_pSwitch[i].m_Type = Index;
 				else
 					m_pSwitch[i].m_Type = 0;
