@@ -29,6 +29,9 @@ enum
 	MAPITEMTYPE_LAYER,
 	MAPITEMTYPE_ENVPOINTS,
 	MAPITEMTYPE_SOUND,
+	// High map item type numbers suggest that they use the alternate
+	// format with UUIDs. See src/engine/shared/datafile.cpp for some of
+	// the implementation.
 
 
 	CURVETYPE_STEP=0,
@@ -151,7 +154,8 @@ enum
 	TILE_BONUS = 95,
 	TILE_TELE_GUN_ENABLE = 96,
 	TILE_TELE_GUN_DISABLE = 97,
-	TILE_NO_TELE_GUN = 98,
+	TILE_ALLOW_TELE_GUN = 98,
+	TILE_ALLOW_BLUE_TELE_GUN = 99,
 	TILE_NPC_START = 104,
 	TILE_SUPER_START,
 	TILE_JETPACK_START,
@@ -419,7 +423,6 @@ struct CMapItemSound
 	int m_SoundDataSize;
 } ;
 
-
 // DDRace
 
 class CTeleTile
